%define anolis_release 2

# Running the tests requires python3-zope-testrunner, which requires
# python3-zope-interface, which requires this package.  Build in bootstrap
# mode to avoid the circular dependency.
%bcond_without bootstrap
%bcond_without docs

# Install doc subpackage files into the main package doc directory
%global _docdir_fmt %{name}

Name:           python-zope-event
Version:        4.5.0
Release:        %{anolis_release}%{?dist}
Summary:        Zope Event Publication
License:        ZPLv2.1
URL:            https://pypi.python.org/pypi/zope.event/
Source0:        %pypi_source zope.event
BuildArch:      noarch

# Update tox.ini, fixes Fedora build failure.  Part of this commit:
# https://github.com/zopefoundation/zope.event/commit/3905db445a7e15f32e62da1fea4d0b4526d40762
Patch0:         %{name}-tox.patch

# Make the tests pass with python 3.  Part of this commit:
# https://github.com/zopefoundation/zope.event/commit/5dd13f35725388c861daaea4fe39c2c1e9976026
Patch1:         %{name}-python3.patch

%description
The zope.event package provides a simple event system. It provides
an event publishing system and a very simple event-dispatching system
on which more sophisticated event dispatching systems can be built.
(For example, a type-based event dispatching system that builds on
zope.event can be found in zope.component.)

%package -n python3-zope-event
Summary:        Zope Event Publication (Python 3)

BuildRequires:  make
BuildRequires:  python3-devel
%if %{with docs}
BuildRequires:  python3-docs
BuildRequires:  %{py3_dist sphinx}
%endif

%description -n python3-zope-event
The zope.event package provides a simple event system. It provides
an event publishing system and a very simple event-dispatching system
on which more sophisticated event dispatching systems can be built.
(For example, a type-based event dispatching system that builds on
zope.event can be found in zope.component.)

This package contains the version for Python 3.

%package -n python3-zope-event-doc
Summary:        Documentation for zope.event

%description -n python3-zope-event-doc
Documentation for %{name}.

%prep
%autosetup -n zope.event-%{version} -p1

# Update the sphinx theme name
sed -i "s/'default'/'classic'/" docs/conf.py

# Use local objects.inv for intersphinx
sed -i "s|\('https://docs\.python\.org/': \)None|\1'%{_docdir}/python3-docs/html/objects.inv'|" docs/conf.py

%generate_buildrequires
%if %{with bootstrap}
%pyproject_buildrequires
%else
%pyproject_buildrequires -t
%endif

%build
%pyproject_wheel

%if %{with docs}
# build the sphinx documents
PYTHONPATH=$PWD/src make -C docs html
rm -f docs/_build/html/.buildinfo
%endif

%install
%pyproject_install

%if %{without bootstrap}
%check
%tox
%endif

%files -n python3-zope-event
%license COPYRIGHT.txt
%license LICENSE.txt
%{python3_sitelib}/zope/event/
%exclude %{python3_sitelib}/zope/event/tests.py*
%exclude %{python3_sitelib}/zope/event/__pycache__/tests*
%dir %{python3_sitelib}/zope/
%{python3_sitelib}/zope.event-*.dist-info
%{python3_sitelib}/zope.event-*-nspkg.pth

%files -n python3-zope-event-doc
%doc CHANGES.rst README.rst
%if %{with docs}
%doc docs/_build/html/
%endif

%changelog
* Wed Mar 13 2024 Zhao Hang <wb-zh951434@alibaba-inc.com> - 4.5.0-2
- Rebuild with python3.11

* Fri May 05 2023 Funda Wang <fundawang@yeah.net> - 4.5.0-1
- Import package for anolis 23
